--- xmove/externs.h.orig	1994-12-01 15:14:38.000000000 -0600
+++ xmove/externs.h	2011-06-13 03:47:06.000000000 -0500
@@ -20,7 +20,5 @@
 
 #include <sys/time.h>
 #include <sys/socket.h>
-#include <malloc.h>
-
 
 #endif /* EXTERNS_H */
